=====================
Ascend.io Tools
=====================

This package contains software that makes your Ascend.io data automation even more awesome.

---------------
Ingestion Tools
---------------
* HL7 to JSON

---------------
Read the Docs
---------------
* `Ascend.io Python SDK Documentation <https://developer.ascend.io/docs/python-sdk>`_
* `Ascend Developer Hub <https://developer.ascend.io>`_
* `Ascend.io <https://www.ascend.io>`_
